@@ -1,3 +1,5 @@
+import configparser
+import os
 import sys
 
 import requests
@@ -5,6 +7,9 @@ import tldextract
 
 from subdomain_takeover_tools.helper.prepare import prepare_domain_name, process_subtake_output
 
+settings = configparser.ConfigParser()
+settings.read(os.path.expanduser('~/.subdomain_takeover_tools.ini'))
+
 
 def bootstrap(is_valid):
     inverse = '--inverse' in sys.argv
@@ -14,6 +19,9 @@ def bootstrap(is_valid):
 
     lines = data.strip().split('\n')
     for line in lines:
+        if not line.strip():
+            continue
+
         if ']\t\t' in line:
             process_subtake_output(is_valid, line, check, inverse, strict)
         else:
